#
# FILE    : MAKEFILE
# PURPOSE : used makefile to update CSET lib, 16 & 32 bits
# DATE    : may, 25 1998
# AUTHOR  : Oleg Lodygensky (lodygens@lal.in2p3.fr)
#

#
# How to use this makefile
#  to update cset32.lib, use nmake which is Microsoft make tool; type:
#     > nmake
#  to update cset16.lib, use make  which is Borland   make tool; type:
#     > make -D16BITS
#


#
# microsoft tools for 32 bits version
#
! ifndef 16BITS
MSROOT = d:\msdev
MSINC = /I$(MSROOT)\include
MSCC = cl
MSOPT = /O2 /c
# MSOPT = /W3 /Gm /GX /Zi /c
MSLIB = lib
MSLINK = link
! endif

#
# borland tools for 16 bits version
#
! ifdef 16BITS
BCROOT = d:\bc45
BCINC = -I$(BCROOT)\include -I.
BCCC  = d:\bc45\bin\bcc
BCOPT = -c -P -L$(BCROOT)\lib -ml
BCLIB = tlib
BCLINK = tlink
! endif

#
# Paths
#
LIBPATH = ..\bin
SRCPATH = ..\src
OBJPATH = ..\bin
EXEPATH = ..\bin

#
# used tools
#
! ifndef 16BITS
CCROOT = $(MSROOT)
CC  = $(MSCC)
LIB = $(MSLIB)
LINK = $(MSLINK)
STDINC = $(MSINC)
OPT = $(MSOPT)
CSETINC = /I..\src
CCOUTPUT = /Fo
LIBOUTPUT = /OUT:$(LIBPATH)
LIBOPT = /DEBUG
LINKOUTPUT =/OUT:$(EXEPATH)
LINKOPT = /LIBPATH:$(CCROOT)\lib /DEBUG
! else
CCROOT = $(BCROOT)
CC  = $(BCCC)
LIB = $(BCLIB)
LINK = $(BCLINK)
STDINC = $(BCINC)
OPT = $(BCOPT)
CSETINC = -I..\src
CCOUTPUT  = -o
LIBOUTPUT = $(LIBPATH)
LINKOUTPUT = $(EXEPATH)
CSET16LIBOBJ = +$(OBJPATH)\carray.obj +$(OBJPATH)\ccarray.obj +$(OBJPATH)\gc.obj +$(OBJPATH)\gcc.obj +$(OBJPATH)\lklist.obj +$(OBJPATH)\hash.obj
! endif


###########################################################
# All
###########################################################
all : dirs cset reg tarray tanchor
	echo all done

dirs :
	if not exist $(LIBPATH) mkdir $(LIBPATH)

help :
        @echo How to use this makefile
        @echo to update cset32.lib, use nmake which is Microsoft make tool; type:
        @echo     > nmake
        @echo to update cset16.lib, use make  which is Borland   make tool; type:
        @echo     > make -D16BITS


clean :
        del $(OBJPATH)\*
        del $(LIBPATH)\*

###########################################################
# CSet library
###########################################################

CSETALL = $(SRCPATH)\carray.c $(SRCPATH)\ccarray.cxx $(SRCPATH)\gc.c $(SRCPATH)\gcc.cxx $(SRCPATH)\lklist.c $(SRCPATH)\hash.c
CSETALLOBJ = $(OBJPATH)\carray.obj $(OBJPATH)\ccarray.obj $(OBJPATH)\gc.obj $(OBJPATH)\gcc.obj $(OBJPATH)\lklist.obj $(OBJPATH)\hash.obj
CSETLIB32NAME = cset32.lib
CSETLIB16NAME = cset16.lib

#
# needed macros
#
! ifndef 16BITS
CSETLIBNAME = $(CSETLIB32NAME)
! else
CSETLIBNAME = $(CSETLIB16NAME)
! endif

! ifndef 16BITS
$(CSETLIBNAME) : $(CSETALLOBJ)
        $(LIB) $(CSETALLOBJ) $(LIBOPT) $(LIBOUTPUT)\$(CSETLIBNAME)
!else
$(CSETLIBNAME) : $(CSETALLOBJ)
        $(LIB) $(LIBOUTPUT)\$(CSETLIBNAME) $(CSET16LIBOBJ)
!endif

cset : $(CSETLIBNAME)
	echo CSet library up to dated

$(OBJPATH)\carray.obj : $(SRCPATH)\carray.c $(SRCPATH)\cset.h
        $(CC) $(STDINC) $(CSETINC) $(OPT) $(CCOUTPUT)$*.obj $(SRCPATH)\carray.c

$(OBJPATH)\ccarray.obj : $(SRCPATH)\ccarray.cxx $(SRCPATH)\gcc.hxx $(SRCPATH)\ccarray.hxx
        $(CC) $(STDINC) $(CSETINC) $(OPT) $(CCOUTPUT)$*.obj $(SRCPATH)\ccarray.cxx

$(OBJPATH)\gc.obj : $(SRCPATH)\gc.c $(SRCPATH)\gc.h
        $(CC) $(STDINC) $(CSETINC) $(OPT) $(CCOUTPUT)$*.obj $(SRCPATH)\gc.c

$(OBJPATH)\gcc.obj : $(SRCPATH)\gcc.cxx $(SRCPATH)\gcc.hxx
        $(CC) $(STDINC) $(CSETINC) $(OPT) $(CCOUTPUT)$*.obj $(SRCPATH)\gcc.cxx

$(OBJPATH)\lklist.obj : $(SRCPATH)\lklist.c $(SRCPATH)\lklistp.h $(SRCPATH)\lklist.h
        $(CC) $(STDINC) $(CSETINC) $(OPT) $(CCOUTPUT)$*.obj $(SRCPATH)\lklist.c

$(OBJPATH)\hash.obj : $(SRCPATH)\hash.c $(SRCPATH)\hash.h
        $(CC) $(STDINC) $(CSETINC) $(OPT) $(CCOUTPUT)$*.obj $(SRCPATH)\hash.c


###########################################################
# Reg library
###########################################################

REGALL = $(SRCPATH)\reg.c $(SRCPATH)\reglex.c $(SRCPATH)\regparse.c
REGALLOBJ = $(OBJPATH)\reg.obj $(OBJPATH)\reglex.obj $(OBJPATH)\regparse.obj
REGLIBNAME = reg.lib

$(REGLIBNAME) : $(REGALLOBJ)
        $(LIB) $(REGALLOBJ) $(LIBOPT) /OUT:$(LIBPATH)\$(REGLIBNAME)

reg : $(REGLIBNAME)
	echo CSet library up to dated

$(OBJPATH)\reg.obj : $(SRCPATH)\reg.c $(SRCPATH)\reg.h
        $(CC) $(STDINC) $(CSETINC) $(OPT) $(CCOUTPUT)$*.obj $(SRCPATH)\reg.c

$(OBJPATH)\regparse.obj : $(SRCPATH)\regparse.c $(SRCPATH)\reg.h
        $(CC) $(STDINC) $(CSETINC) $(OPT) $(CCOUTPUT)$*.obj $(SRCPATH)\regparse.c

$(OBJPATH)\reglex.obj : $(SRCPATH)\reglex.c $(SRCPATH)\reg.h
        $(CC) $(STDINC) $(CSETINC) $(OPT) $(CCOUTPUT)$*.obj $(SRCPATH)\reglex.c

###########################################################
# TArray
###########################################################

TARRAYALL = $(SRCPATH)\tarray.c
TARRAYALLOBJ = $(OBJPATH)\tarray.obj $(LIBPATH)\$(CSETLIBNAME)
TARRAYNAME = tarray.exe

tarray : $(TARRAYNAME) 
	echo Tarray up to dated

$(TARRAYNAME) : $(TARRAYALLOBJ) cset
	$(LINK) $(LINKOPT) $(TARRAYALLOBJ) $(LINKOUTPUT)\$(TARRAYNAME)

$(OBJPATH)\tarray.obj : $(SRCPATH)\tarray.c $(SRCPATH)\cset.h $(SRCPATH)\gc.h
        $(CC) $(STDINC) $(CSETINC) $(OPT) $(CCOUTPUT)$*.obj $(SRCPATH)\tarray.c

###########################################################
# TAnchor
###########################################################

TANCHORALL = $(SRCPATH)\tarray.c
TANCHORALLOBJ = $(OBJPATH)\tarray.obj $(LIBPATH)\$(CSETLIBNAME)
TANCHORNAME = tanchor.exe

tanchor : $(TANCHORNAME) 
	echo TAnchor up to dated

$(TANCHORNAME) : $(TANCHORALLOBJ) cset
	$(LINK) $(LINKOPT) $(TANCHORALLOBJ) $(LINKOUTPUT)\$(TANCHORNAME)

$(OBJPATH)\tanchor.obj : $(SRCPATH)\tanchor.c $(SRCPATH)\cset.h $(SRCPATH)\gc.h
        $(CC) $(STDINC) $(CSETINC) $(OPT) $(CCOUTPUT)$*.obj $(SRCPATH)\tanchor.c
